# Fast Event Voxel Builder
[\[Codeberg Repo\]](https://codeberg.org/ybh1998/EventVoxelBuilder/)
[\[API Document\]](https://ybh1998.codeberg.page/EventVoxelBuilder/)

### Warning: Very Unstable API!
This is currently a rush project for CVPR 2024 and the API will definitely be rewritten after the DDL.

### To run the example Python codes or your own Python code
1. Download `event-voxel-builder-*.whl` under \
[\[releases\]](https://codeberg.org/ybh1998/EventVoxelBuilder/releases/) and install using `pip install`, or \
install from [\[PyPI\]](https://pypi.org/project/event-voxel-builder/).
2. Run Python example codes in `examples` or your own codes.

Copyright (c) 2023 Bohan Yu. All rights reserved. \
EventVoxelBuilder is free software licensed under GNU Affero General Public License version 3 or latter.
